CREPManager | unified-mandala - v1.0.0
Description: Documentation for unified-mandala

# Class CREPManager

- Defined in packages/crep-engine/CREPManager.ts:4

#####
Index

### Constructors

constructor

### Properties

crepHistory

### Methods

addCREPEntry
getCREPHistory

## Constructors

### constructor

- new CREPManager(): CREPManager

- #### Returns CREPManager

  - Defined in packages/crep-engine/CREPManager.ts:7

## Properties

### `Private` crepHistory

crepHistory: CREPEntry[] = []

- Defined in packages/crep-engine/CREPManager.ts:5

## Methods

### addCREPEntry

- addCREPEntry(C, R, E, P): void

- #### Parameters

  - C: number
  - R: number
  - E: number
  - P: number

  #### Returns void

  - Defined in packages/crep-engine/CREPManager.ts:22

### getCREPHistory

- getCREPHistory(): CREPEntry[]

- #### Returns CREPEntry[]

  - Defined in packages/crep-engine/CREPManager.ts:29